# Templates

Templates to generate python scripts.

## User's Guide

The {py:class}`~abqpy.template.ScriptTemplate` class provides a simple interface to generate python scripts from
templates.

## CompressionTemplate

```{eval-rst}
.. autoclass:: abqpy.template.CompressionTemplate

```

## ScriptTemplate

```{eval-rst}
.. autoclass:: abqpy.template.ScriptTemplate
   :members:
   :special-members: __init__
   :show-inheritance:
```
